@@ -14,7 +14,6 @@ from keras import optimizers, regularizers, initializers
 from keras.utils import plot_model
 from keras.losses import mse, binary_crossentropy
 from scipy.sparse import csr_matrix
-from tools.plotting import plotCorrelation, run_embedding, plotEmbedding
 
 def sampling(args):
     z_mean, z_log_var = args
@@ -675,16 +674,16 @@ class VIPCCA(object):
         self.conf.net.train(self.conf.adata_all, epochs=self.conf.epochs, model_file=self.conf.model_file)
         return self.conf.net.integrate(self.conf.adata_all, save=self.conf.save)
 
-    def plotEmbedding(self, eps=[], group_by="Batch", min_dist=0.5):
-        self.build()
-        for epoch in eps:
-            test_result_path = self.conf.res_path + "e%04d_" % epoch
-            self.conf.net.vae.load_weights(self.conf.res_path + "weights%04d.h5" % epoch)
-            adata_transform = self.conf.net.integrate(self.conf.adata_all, save=False)
-            plotCorrelation(adata_transform.raw.X, adata_transform.X, result_path=test_result_path)
-            run_embedding(adata_transform, path=test_result_path, method="umap", min_dist=min_dist)
-            plotEmbedding(adata_transform, path=test_result_path, method='umap', group_by=group_by,
-                          legend_loc="right margin")
+    # def plotEmbedding(self, eps=[], group_by="Batch", min_dist=0.5):
+    #     self.build()
+    #     for epoch in eps:
+    #         test_result_path = self.conf.res_path + "e%04d_" % epoch
+    #         self.conf.net.vae.load_weights(self.conf.res_path + "weights%04d.h5" % epoch)
+    #         adata_transform = self.conf.net.integrate(self.conf.adata_all, save=False)
+    #         plotCorrelation(adata_transform.raw.X, adata_transform.X, result_path=test_result_path)
+    #         run_embedding(adata_transform, path=test_result_path, method="umap", min_dist=min_dist)
+    #         plotEmbedding(adata_transform, path=test_result_path, method='umap', group_by=group_by,
+    #                       legend_loc="right margin")
 
 #
 # if __name__ == "__main__":
